@@ -141,6 +141,9 @@ Out of the box implementation of the Construct without any override will set the
 
 © Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
